# flake.nix
{
  description = "My Home Manager configuration";

  inputs = {
    nixos-hardware.url = "github:NixOS/nixos-hardware/master";

    nixpkgs-stable.url = "github:nixos/nixpkgs/nixos-24.11";
    nixpkgs.url = "github:nixos/nixpkgs/nixos-24.11";

    home-manager = {
      url = "github:nix-community/home-manager/release-24.11";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    nix-flatpak.url = "github:gmodena/nix-flatpak"; # unstable branch. Use github:gmodena/nix-flatpak/?ref=<tag> to pin releases.

    kmonad = {
      url = "git+https://github.com/kmonad/kmonad?submodules=1&dir=nix";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    musnix  = {
      url = "github:musnix/musnix";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    audio = {
      url = "github:polygon/audio.nix";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    nix-ld.url = "github:Mic92/nix-ld";
    nix-ld.inputs.nixpkgs.follows = "nixpkgs";
  };

  outputs = inputs @ {nixpkgs, nixpkgs-stable, home-manager, audio, nix-flatpak, kmonad, musnix, nix-ld, ... }: {
    nixosConfigurations = {
      eddie = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        modules = [ 
          nix-flatpak.nixosModules.nix-flatpak
          kmonad.nixosModules.default
          musnix.nixosModules.musnix
          nix-ld.nixosModules.nix-ld
	        ./system/eddie/configuration.nix
        ];
      };
    };
   
   
    homeConfigurations = {
      home-manager.useGlobalPkgs = true;
      home-manager.useUserPackages = true;

      "emenel" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = {
          inherit inputs;
          pkgs-stable = nixpkgs-stable.legacyPackages.x86_64-linux;
        };

        modules = [
          nix-flatpak.homeManagerModules.nix-flatpak
          ./home/home.nix
        ];
      };
    };  
  };
}
